---
title: <span class="badge builder"></span> SpecialValueMap
---
# <span class="badge builder"></span> SpecialValueMap

## Constructor

```python
SpecialValueMap()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> dashboard.SpecialValueMap
```

### <span class="badge object-method"></span> options

```python
def options(options: cogbuilder.Builder[dashboard.DashboardSpecialValueMapOptions]) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [SpecialValueMap](./object-SpecialValueMap.md)
